@@ -10,5 +10,5 @@ func main() {
 	emojiKeyword := flag.String("e", ":beer: Beer!!!", "emoji name")
 	flag.Parse()
 
-	emoji.Println(*emojiKeyword)
+	emoji.Print(*emojiKeyword)
 }
